@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 ########################################################################
 #
 #       License: BSD
@@ -10,9 +12,12 @@
 
 """Utilities to be used mainly by the Index class."""
 
+import sys
 import math
 import numpy
 
+from tables._past import previous_api
+
 
 # Hints for chunk/slice/block/superblock computations:
 # - The slicesize should not exceed 2**32 elements (because of
@@ -99,7 +104,7 @@ def computeblocksize(expectedrows, compoundsize, lowercompoundsize):
     return size
 
 
-def calcChunksize(expectedrows, optlevel=6, indsize=4, memlevel=4):
+def calc_chunksize(expectedrows, optlevel=6, indsize=4, memlevel=4):
     """Calculate the HDF5 chunk size for index and sorted arrays.
 
     The logic to do that is based purely in experiments playing with
@@ -129,19 +134,21 @@ def calcChunksize(expectedrows, optlevel=6, indsize=4, memlevel=4):
     sizes = (superblocksize, blocksize, slicesize, chunksize)
     return sizes
 
+calcChunksize = previous_api(calc_chunksize)
+
 
 def ccs_ultralight(optlevel, chunksize, slicesize):
     """Correct the slicesize and the chunksize based on optlevel."""
 
     if optlevel in (0, 1, 2):
         slicesize //= 2
-        slicesize += optlevel*slicesize
+        slicesize += optlevel * slicesize
     elif optlevel in (3, 4, 5):
-        slicesize *= optlevel-1
+        slicesize *= optlevel - 1
     elif optlevel in (6, 7, 8):
-        slicesize *= optlevel-1
+        slicesize *= optlevel - 1
     elif optlevel == 9:
-        slicesize *= optlevel-1
+        slicesize *= optlevel - 1
     return chunksize, slicesize
 
 
@@ -157,7 +164,8 @@ def ccs_light(optlevel, chunksize, slicesize):
     elif optlevel == 9:
         # Reducing the chunksize and enlarging the slicesize is the
         # best way to reduce the entropy with the current algorithm.
-        chunksize /= 2; slicesize *= 2
+        chunksize /= 2
+        slicesize *= 2
     return chunksize, slicesize
 
 
@@ -213,7 +221,7 @@ def calcoptlevels(nblocks, optlevel, indsize):
 def col_light(nblocks, optlevel):
     """Compute the optimizations to be done for light indexes."""
 
-    optmedian, optstarts, optstops, optfull = (False,)*4
+    optmedian, optstarts, optstops, optfull = (False,) * 4
 
     if 0 < optlevel <= 3:
         optmedian = True
@@ -228,7 +236,7 @@ def col_light(nblocks, optlevel):
 def col_medium(nblocks, optlevel):
     """Compute the optimizations to be done for medium indexes."""
 
-    optmedian, optstarts, optstops, optfull = (False,)*4
+    optmedian, optstarts, optstops, optfull = (False,) * 4
 
     # Medium case
     if nblocks <= 1:
@@ -252,7 +260,7 @@ def col_medium(nblocks, optlevel):
 def col_full(nblocks, optlevel):
     """Compute the optimizations to be done for full indexes."""
 
-    optmedian, optstarts, optstops, optfull = (False,)*4
+    optmedian, optstarts, optstops, optfull = (False,) * 4
 
     # Full case
     if nblocks <= 1:
@@ -280,13 +288,13 @@ def get_reduction_level(indsize, optlevel, slicesize, chunksize):
         [4, 4, 4, 4, 2, 2, 2, 1, 1, 1],  # 16-bit indices (light)
         [2, 2, 2, 2, 1, 1, 1, 1, 1, 1],  # 32-bit indices (medium)
         [1, 1, 1, 1, 1, 1, 1, 1, 1, 1],  # 64-bit indices (full)
-        ]
-    isizes = {1:0, 2:1, 4:2, 8:3}
+    ]
+    isizes = {1: 0, 2: 1, 4: 2, 8: 3}
     rlevel = rlevels[isizes[indsize]][optlevel]
     # The next cases should only happen in tests
     if rlevel >= slicesize:
         rlevel = 1
-    if slicesize <= chunksize*rlevel:
+    if slicesize <= chunksize * rlevel:
         rlevel = 1
     if indsize == 8:
         # Ensure that, for full indexes we will never perform a reduction.
@@ -295,7 +303,6 @@ def get_reduction_level(indsize, optlevel, slicesize, chunksize):
     return rlevel
 
 
-
 # Python implementations of NextAfter and NextAfterF
 #
 # These implementations exist because the standard function
@@ -307,22 +314,19 @@ def get_reduction_level(indsize, optlevel, slicesize, chunksize):
 #
 # Thanks to Shack Toms shack@livedata.com for NextAfter and NextAfterF
 # implementations in Python. 2004-10-01
-
-#epsilon  = math.ldexp(1.0, -53) # smallest double such that 0.5+epsilon != 0.5
-#epsilonF = math.ldexp(1.0, -24) # smallest float such that 0.5+epsilonF != 0.5
-
-#maxFloat = float(2**1024 - 2**971)  # From the IEEE 754 standard
-#maxFloatF = float(2**128 - 2**104)  # From the IEEE 754 standard
-
-#minFloat  = math.ldexp(1.0, -1022) # min positive normalized double
-#minFloatF = math.ldexp(1.0, -126)  # min positive normalized float
-
-#smallEpsilon  = math.ldexp(1.0, -1074) # smallest increment for doubles < minFloat
-#smallEpsilonF = math.ldexp(1.0, -149)  # smallest increment for floats < minFloatF
-
+# epsilon  = math.ldexp(1.0, -53) # smallest double such that 0.5 + epsilon != 0.5
+# epsilonF = math.ldexp(1.0, -24) # smallest float such that 0.5 + epsilonF
+# != 0.5
+# maxFloat = float(2**1024 - 2**971)  # From the IEEE 754 standard
+# maxFloatF = float(2**128 - 2**104)  # From the IEEE 754 standard
+# minFloat  = math.ldexp(1.0, -1022) # min positive normalized double
+# minFloatF = math.ldexp(1.0, -126)  # min positive normalized float
+# smallEpsilon  = math.ldexp(1.0, -1074) # smallest increment for doubles < minFloat
+# smallEpsilonF = math.ldexp(1.0, -149)  # smallest increment for floats <
+# minFloatF
 infinity = math.ldexp(1.0, 1023) * 2
-infinityF = math.ldexp(1.0, 128)
-#Finf = float("inf")  # Infinite in the IEEE 754 standard (not avail in Win)
+infinityf = math.ldexp(1.0, 128)
+# Finf = float("inf")  # Infinite in the IEEE 754 standard (not avail in Win)
 
 # A portable representation of NaN
 # if sys.byteorder == "little":
@@ -332,136 +336,59 @@ infinityF = math.ldexp(1.0, 128)
 # else:
 #     raise ValueError("Byteorder '%s' not supported!" % sys.byteorder)
 # This one seems better
-#testNaN = infinity - infinity
+# testNaN = infinity - infinity
 
 # "infinity" for several types
-infinityMap = {
-    'bool':    [0,          1],
-    'int8':    [-2**7,      2**7-1],
-    'uint8':   [0,          2**8-1],
-    'int16':   [-2**15,     2**15-1],
-    'uint16':  [0,          2**16-1],
-    'int32':   [-2**31,     2**31-1],
-    'uint32':  [0,          2**32-1],
-    'int64':   [-2**63,     2**63-1],
-    'uint64':  [0,          2**64-1],
-    'float32': [-infinityF, infinityF],
-    'float64': [-infinity,  infinity],
+infinitymap = {
+    'bool': [0, 1],
+    'int8': [-2**7, 2**7 - 1],
+    'uint8': [0, 2**8 - 1],
+    'int16': [-2**15, 2**15 - 1],
+    'uint16': [0, 2**16 - 1],
+    'int32': [-2**31, 2**31 - 1],
+    'uint32': [0, 2**32 - 1],
+    'int64': [-2**63, 2**63 - 1],
+    'uint64': [0, 2**64 - 1],
+    'float32': [-infinityf, infinityf],
+    'float64': [-infinity, infinity],
 }
 
 if hasattr(numpy, 'float16'):
-    infinityMap['float16'] = [-numpy.float16(numpy.inf),  numpy.float16(numpy.inf)]
+    infinitymap['float16'] = [-numpy.float16(numpy.inf),
+                              numpy.float16(numpy.inf)]
+if hasattr(numpy, 'float96'):
+    infinitymap['float96'] = [-numpy.float96(numpy.inf),
+                              numpy.float96(numpy.inf)]
+if hasattr(numpy, 'float128'):
+    infinitymap['float128'] = [-numpy.float128(numpy.inf),
+                               numpy.float128(numpy.inf)]
+
+# deprecated API
+infinityMap = infinitymap
+infinityF = infinityf
 
 # Utility functions
-def infType(dtype, itemsize, sign=+1):
+
+
+def inftype(dtype, itemsize, sign=+1):
     """Return a superior limit for maximum representable data type"""
 
     assert sign in [-1, +1]
 
     if dtype.kind == "S":
         if sign < 0:
-            return "\x00"*itemsize
+            return b"\x00" * itemsize
         else:
-            return "\xff"*itemsize
+            return b"\xff" * itemsize
     try:
-        return infinityMap[dtype.name][sign >= 0]
+        return infinitymap[dtype.name][sign >= 0]
     except KeyError:
         raise TypeError("Type %s is not supported" % dtype.name)
 
-
-## This check does not work for Python 2.2.x or 2.3.x (!)
-#def IsNaN(x):
-#    """a simple check for x is NaN, assumes x is float"""
-#    return x != x
+infType = previous_api(inftype)
 
 
-#def PyNextAfter(x, y):
-#    """returns the next float after x in the direction of y if possible, else returns x"""
-#    # if x or y is Nan, we don't do much
-#    if IsNaN(x) or IsNaN(y):
-#        return x
-#
-#    # we can't progress if x == y
-#    if x == y:
-#        return x
-#
-#    # similarly if x is infinity
-#    if x >= infinity or x <= -infinity:
-#        return x
-#
-#    # return small numbers for x very close to 0.0
-#    if -minFloat < x < minFloat:
-#        if y > x:
-#            return x + smallEpsilon
-#        else:
-#            return x - smallEpsilon  # we know x != y
-#
-#    # it looks like we have a normalized number
-#    # break x down into a mantissa and exponent
-#    m, e = math.frexp(x)
-#
-#    # all the special cases have been handled
-#    if y > x:
-#        m += epsilon
-#    else:
-#        m -= epsilon
-#
-#    return math.ldexp(m, e)
-
-
-#def PyNextAfterF(x, y):
-#    """returns the next IEEE single after x in the direction of y if possible, else returns x"""
-#
-#    # if x or y is Nan, we don't do much
-#    if IsNaN(x) or IsNaN(y):
-#        return x
-#
-#    # we can't progress if x == y
-#    if x == y:
-#        return x
-#
-#    # similarly if x is infinity
-#    if x >= infinityF:
-#        return infinityF
-#    elif x <= -infinityF:
-#        return -infinityF
-#
-#    # return small numbers for x very close to 0.0
-#    if -minFloatF < x < minFloatF:
-#        # since Python uses double internally, we
-#        # may have some extra precision to toss
-#        if x > 0.0:
-#            extra = x % smallEpsilonF
-#        elif x < 0.0:
-#            extra = x % -smallEpsilonF
-#        else:
-#            extra = 0.0
-#        if y > x:
-#            return x - extra + smallEpsilonF
-#        else:
-#            return x - extra - smallEpsilonF  # we know x != y
-#
-#    # it looks like we have a normalized number
-#    # break x down into a mantissa and exponent
-#    m, e = math.frexp(x)
-#
-#    # since Python uses double internally, we
-#    # may have some extra precision to toss
-#    if m > 0.0:
-#        extra = m % epsilonF
-#    else:  # we have already handled m == 0.0 case
-#        extra = m % -epsilonF
-#
-#    # all the special cases have been handled
-#    if y > x:
-#        m += epsilonF - extra
-#    else:
-#        m -= epsilonF - extra
-#
-#    return math.ldexp(m, e)
-
-
-def StringNextAfter(x, direction, itemsize):
+def string_next_after(x, direction, itemsize):
     """Return the next representable neighbor of x in the appropriate
     direction."""
 
@@ -470,36 +397,44 @@ def StringNextAfter(x, direction, itemsize):
     # Pad the string with \x00 chars until itemsize completion
     padsize = itemsize - len(x)
     if padsize > 0:
-        x += "\x00"*padsize
-    xlist = list(x); xlist.reverse()
+        x += b"\x00" * padsize
+    if sys.version_info[0] < 3:
+        xlist = list(x)
+    else:
+        # int.to_bytes is not available in Python < 3.2
+        # xlist = [i.to_bytes(1, sys.byteorder) for i in x]
+        xlist = [bytes([i]) for i in x]
+    xlist.reverse()
     i = 0
     if direction > 0:
-        if xlist == "\xff"*itemsize:
+        if xlist == b"\xff" * itemsize:
             # Maximum value, return this
-            return "".join(xlist)
+            return b"".join(xlist)
         for xchar in xlist:
             if ord(xchar) < 0xff:
-                xlist[i] = chr(ord(xchar)+1)
+                xlist[i] = chr(ord(xchar) + 1).encode('ascii')
                 break
             else:
-                xlist[i] = "\x00"
+                xlist[i] = b"\x00"
             i += 1
     else:
-        if xlist == "\x00"*itemsize:
+        if xlist == b"\x00" * itemsize:
             # Minimum value, return this
-            return "".join(xlist)
+            return b"".join(xlist)
         for xchar in xlist:
             if ord(xchar) > 0x00:
-                xlist[i] = chr(ord(xchar)-1)
+                xlist[i] = chr(ord(xchar) - 1).encode('ascii')
                 break
             else:
-                xlist[i] = "\xff"
+                xlist[i] = b"\xff"
             i += 1
     xlist.reverse()
-    return "".join(xlist)
+    return b"".join(xlist)
+
+StringNextAfter = previous_api(string_next_after)
 
 
-def IntTypeNextAfter(x, direction, itemsize):
+def int_type_next_after(x, direction, itemsize):
     """Return the next representable neighbor of x in the appropriate
     direction."""
 
@@ -508,19 +443,21 @@ def IntTypeNextAfter(x, direction, itemsize):
     # x is guaranteed to be either an int or a float
     if direction < 0:
         if isinstance(x, int):
-            return x-1
+            return x - 1
         else:
-            #return int(PyNextAfter(x,x-1))
-            return int(numpy.nextafter(x,x-1))
+            # return int(PyNextAfter(x, x - 1))
+            return int(numpy.nextafter(x, x - 1))
     else:
         if isinstance(x, int):
-            return x+1
+            return x + 1
         else:
-            #return int(PyNextAfter(x,x+1))+1
-            return int(numpy.nextafter(x,x+1))+1
+            # return int(PyNextAfter(x,x + 1)) + 1
+            return int(numpy.nextafter(x, x + 1)) + 1
+
+IntTypeNextAfter = previous_api(int_type_next_after)
 
 
-def BoolTypeNextAfter(x, direction, itemsize):
+def bool_type_next_after(x, direction, itemsize):
     """Return the next representable neighbor of x in the appropriate
     direction."""
 
@@ -532,6 +469,8 @@ def BoolTypeNextAfter(x, direction, itemsize):
     else:
         return True
 
+BoolTypeNextAfter = previous_api(bool_type_next_after)
+
 
 def nextafter(x, direction, dtype, itemsize):
     """Return the next representable neighbor of x in the appropriate
@@ -544,33 +483,32 @@ def nextafter(x, direction, dtype, itemsize):
         return x
 
     if dtype.kind == "S":
-        return StringNextAfter(x, direction, itemsize)
+        return string_next_after(x, direction, itemsize)
 
     if dtype.kind in ['b']:
-        return BoolTypeNextAfter(x, direction, itemsize)
+        return bool_type_next_after(x, direction, itemsize)
     elif dtype.kind in ['i', 'u']:
-        return IntTypeNextAfter(x, direction, itemsize)
+        return int_type_next_after(x, direction, itemsize)
     elif dtype.kind == "f":
         if direction < 0:
             return numpy.nextafter(x, x - 1)
         else:
             return numpy.nextafter(x, x + 1)
 
-    #elif dtype.name == "float32":
+    # elif dtype.name == "float32":
     #    if direction < 0:
     #        return PyNextAfterF(x,x-1)
     #    else:
-    #        return PyNextAfterF(x,x+1)
-    #elif dtype.name == "float64":
+    #        return PyNextAfterF(x,x + 1)
+    # elif dtype.name == "float64":
     #    if direction < 0:
     #        return PyNextAfter(x,x-1)
     #    else:
-    #        return PyNextAfter(x,x+1)
+    #        return PyNextAfter(x,x + 1)
 
     raise TypeError("data type ``%s`` is not supported" % dtype)
 
 
-
 ## Local Variables:
 ## mode: python
 ## py-indent-offset: 4
